@@ -5,12 +5,12 @@ use strict;
 use warnings;
 use Moo;
 with qw( App::Midgen::Roles );
+use App::Midgen::Output;
 
-our $VERSION = '0.07';
-use English qw( -no_match_vars ); # Avoids regex performance penalty
+our $VERSION = '0.08';
+use English qw( -no_match_vars ); # Avoids reg-ex performance penalty
 local $OUTPUT_AUTOFLUSH = 1;
 
-use autodie;
 use CPAN;
 use Carp;
 use Cwd;
@@ -37,7 +37,9 @@ use constant {
 sub run {
 	my $self = shift;
 	$self->initialise();
-	$self->first_package_name();
+	try {
+		$self->first_package_name();
+	};
 	$self->output_header();
 
 	$self->find_required_modules();
@@ -58,12 +60,13 @@ sub run {
 #######
 sub initialise {
 	my $self = shift;
+	$self->{output} = App::Midgen::Output->new;
 
 	# stop rlib from Fing all over cwd
 	$self->{working_dir} = cwd();
 	say 'working in dir: ' . $self->{working_dir} if $self->{debug};
 
-	# set up cpan bit's as well as checking we are upto date
+	# set up cpan bit's as well as checking we are up to date
 	CPAN::HandleConfig->load;
 	CPAN::Shell::setup_output;
 	CPAN::Index->reload;
@@ -82,14 +85,14 @@ sub first_package_name {
 
 	p $self->{package_names} if $self->{debug};
 
-	# We will assume the first one found is our Package Name
+	# We will assume the first package found is our Package Name, pot lock :)
 	$self->{package_name} = $self->{package_names}[0];
 	say 'Package: ' . $self->{package_name} if $self->{verbose};
 
 	return;
 }
 #######
-# first_package_name
+# find_package_name
 #######
 sub find_package_names {
 	my $self     = shift;
@@ -100,6 +103,8 @@ sub find_package_names {
 
 	# Load a Document from a file
 	my $document = PPI::Document->new($filename);
+
+	# Extract package names
 	push @{ $self->{package_names} }, $document->find_first('PPI::Statement::Package')->namespace;
 
 	return;
@@ -167,9 +172,7 @@ sub find_makefile_requires {
 		say 'looking for requires in -> ' . $filename;
 	}
 
-	# my @items = ();
 	my $ppi_i = $document->find('PPI::Statement::Include');
-
 	p $ppi_i if $self->{debug};
 
 	if ($ppi_i) {
@@ -185,9 +188,6 @@ sub find_makefile_requires {
 					@modules = @base_parent_modules;
 				}
 
-				# try{
-				# @modules = $self->base_parent( $include->module, $include->content, $include->pragma );
-				# };
 			}
 
 			foreach my $module (@modules) {
@@ -207,6 +207,7 @@ sub find_makefile_requires {
 				next if $module eq NONE;
 				if ( $module =~ /^$self->{package_name}/sxm ) {
 
+					# Tommy here is were we ignore current package children
 					# don't include our own packages here
 					next;
 				}
@@ -220,7 +221,6 @@ sub find_makefile_requires {
 				}
 
 				$self->store_modules( 'requires', $module );
-
 			}
 		}
 	}
@@ -241,7 +241,7 @@ sub find_makefile_test_requires {
 		say 'looking for test_requires in: ' . $filename;
 	}
 
-	# Load a Document from a file
+	# Load a Document from a file and check use and require contents
 	my $document = PPI::Document->new($filename);
 	my $ppi_i    = $document->find('PPI::Statement::Include');
 
@@ -259,19 +259,36 @@ sub find_makefile_test_requires {
 			}
 
 			$self->process_found_modules( \@modules );
-
 		}
 	}
 
 	# Hack for use_ok in test files, Ouch!
+	# Now lets double check the ptq-Single hidden in a test file
 	my $ppi_tqs = $document->find('PPI::Token::Quote::Single');
 	if ($ppi_tqs) {
 		my @modules;
 		foreach my $include ( @{$ppi_tqs} ) {
-			if ( $include->content =~ /::/ && $include->content !~ /main/ ) {
+			if ( $include->content =~ /::/ && $include->content !~ /main/ && !$include->content =~ /use/ ) {
 				my $module = $include->content;
 				$module =~ s/^[']//;
 				$module =~ s/[']$//;
+				$module =~ s/(\s[\w|\s]+)$//;
+				p $module if $self->{debug};
+
+				# if we have found it already ignore it
+				if ( !$self->{requires}{$module} ) {
+					push @modules, $module;
+				}
+			}
+			if ( $include->content =~ /::/ && $include->content =~ /use/ ) {
+				my $module = $include->content;
+
+				#ToDo test for duplicates and rubbish, part 1 done more to do
+
+				$module =~ s/^[']//;
+				$module =~ s/[']$//;
+				$module =~ s/^use\s//;
+				p $module if $self->{debug};
 
 				# if we have found it already ignore it
 				if ( !$self->{requires}{$module} ) {
@@ -280,13 +297,40 @@ sub find_makefile_test_requires {
 			}
 
 			# if we found a modules, process it
-			if ( $#modules > 0 ) {
+			if ( scalar @modules > 0 ) {
 				p @modules if $self->{debug};
 				$self->process_found_modules( \@modules );
 			}
 		}
 	}
 
+	# Now lets double check the ptq-Doubles hidden in a test file - why O why - rtfm pbp
+	my $ppi_tqd = $document->find('PPI::Token::Quote::Double');
+	if ($ppi_tqd) {
+		my @modules;
+		foreach my $include ( @{$ppi_tqd} ) {
+
+			if ( $include->content =~ /::/ && $include->content =~ /use/ ) {
+				my $module = $include->content;
+				$module =~ s/^["]//;
+				$module =~ s/["]$//;
+				$module =~ s/^use\s//;
+				$module =~ s/(\s[\s|\w|\n|.|;]+)$//;
+				p $module if $self->{debug};
+
+				# if we have found it already ignore it
+				if ( !$self->{requires}{$module} ) {
+					push @modules, $module;
+				}
+			}
+
+			# if we found a modules, process it
+			if ( scalar @modules > 0 ) {
+				p @modules if $self->{debug};
+				$self->process_found_modules( \@modules );
+			}
+		}
+	}
 
 	return;
 }
@@ -350,7 +394,7 @@ sub store_modules {
 
 		if ( $mod->cpan_version ne 'undef' ) {
 
-			# alociate current cpan version against module name
+			# allocate current cpan version against module name
 			$mod_in_cpan = 1;
 		}
 
@@ -363,12 +407,15 @@ sub store_modules {
 			$self->{$require_type}{$module} = 0;
 		} elsif ( $module !~ /^t::/ && $self->{requires}{$module} ) {
 			$self->{$require_type}{$module} = 0;
+		} elsif ( not defined $self->{requires}{$module} ) {
+			$self->{$require_type}{$module} = 0;
 		}
+
 	}
 	finally {
 		if ( $mod_in_cpan && !$self->{requires}{$module} ) {
 
-			# alociate current cpan version against module name
+			# allocate current cpan version against module name
 			$self->{$require_type}{$module} = $mod->cpan_version;
 		}
 	};
@@ -436,7 +483,8 @@ sub remove_noisy_children {
 
 		if ( $sorted_modules[$n] =~ /^$sorted_modules[$n-1]::/ ) {
 
-			# Checking for one degree of seperation ie A::B -> A::B::C is ok but A::B::C::D is not
+			# Checking for one degree of separation
+			# ie A::B -> A::B::C is ok but A::B::C::D is not
 			if ( ( $parent_score + 1 ) == $child_score ) {
 
 				# Test for same version number
@@ -466,27 +514,20 @@ sub remove_noisy_children {
 sub output_header {
 	my $self = shift;
 
-	# Let's get the current version of Module::Install::DSL
-	my $mod = CPAN::Shell->expand( 'Module', 'inc::Module::Install::DSL' );
-	my $package_name = $self->{package_name};
-	$package_name =~ s{::}{/};
-
 	given ( $self->{output_format} ) {
 
-		# when ('mi') {
-		#ToDo add mi to output_top
-		# }
+		when ('mi') {
+			$self->{output}->header_mi( $self->{package_name} );
+		}
 		when ('dsl') {
-			print "\n";
-			say 'use inc::Module::Install::DSL ' . $mod->cpan_version . ';';
-			print "\n";
-			say 'all_from lib/' . $package_name . '.pm';
-			say 'requires_from lib/' . $package_name . '.pm';
+			$self->{output}->header_dsl( $self->{package_name} );
+		}
+		when ('build') {
+			$self->{output}->header_build( $self->{package_name} );
+		}
+		when ('dzil') {
+			$self->{output}->header_dzil( $self->{package_name} );
 		}
-
-		# when ('build') {
-		#ToDo add build  to output_top
-		# }
 	}
 	return;
 }
@@ -498,43 +539,22 @@ sub output_main_body {
 	my $title        = shift || 'title missing';
 	my $required_ref = shift || return;
 
-	print "\n";
+	given ( $self->{output_format} ) {
 
-	my $pm_length = 0;
-	foreach my $module_name ( sort keys %{$required_ref} ) {
-		if ( length $module_name > $pm_length ) {
-			$pm_length = length $module_name;
+		when ('mi') {
+			$self->{output}->body_mi($title, $required_ref);
+		}
+		when ('dsl') {
+			$self->{output}->body_dsl($title, $required_ref );
+		}
+		when ('build') {
+			$self->{output}->body_build($title, $required_ref );
+		}
+		when ('dzil') {
+			$self->{output}->body_dzil($title, $required_ref );
 		}
 	}
 
-	say $title . ' => {' if $self->{output_format} eq 'build';
-
-	foreach my $module_name ( sort keys %{$required_ref} ) {
-		given ( $self->{output_format} ) {
-			when ('mi') {
-				if ( $module_name =~ /^Win32/sxm ) {
-					my $sq_key = "'$module_name'";
-					printf "%s %-*s => '%s' if win32;\n", $title, $pm_length + 2, $sq_key,
-						$required_ref->{$module_name};
-				} else {
-					my $sq_key = "'$module_name'";
-					printf "%s %-*s => '%s';\n", $title, $pm_length + 2, $sq_key, $required_ref->{$module_name};
-				}
-			}
-			when ('dsl') {
-				if ( $module_name =~ /^Win32/sxm ) {
-					printf "%s %-*s %s if win32\n", $title, $pm_length, $module_name, $required_ref->{$module_name};
-				} else {
-					printf "%s %-*s %s\n", $title, $pm_length, $module_name, $required_ref->{$module_name};
-				}
-			}
-			when ('build') {
-				my $sq_key = "'$module_name'";
-				printf "\t %-*s => '%s',\n", $pm_length + 2, $sq_key, $required_ref->{$module_name};
-			}
-		}
-	}
-	say '},' if $self->{output_format} eq 'build';
 	return;
 }
 #######
@@ -542,32 +562,23 @@ sub output_main_body {
 #######
 sub output_footer {
 	my $self = shift;
-
+	
 	given ( $self->{output_format} ) {
 
-		# when ('mi') {
-
-		# }
+		when ('mi') {
+			$self->{output}->footer_mi( );
+		}
 		when ('dsl') {
-			if ( $self->{verbose} ) {
-				print "\n";
-				say '#ToDo you should consider completing the following';
-				say "homepage\t...";
-				say "bugtracker\t...";
-				say "repository\t...";
-			}
-			print "\n";
-			if ( defined -d './share' ) {
-				say 'install_share';
-				print "\n";
-			}
-			say 'no_index directory  qw{ t xt eg share inc privinc }';
+			$self->{output}->footer_dsl( );
+		}
+		when ('build') {
+			$self->{output}->footer_build( );
+		}
+		when ('dzil') {
+			$self->{output}->footer_dzil( );
 		}
-
-		# when ('build') {
-
-		# }
 	}
+
 	return;
 }
 
@@ -582,85 +593,31 @@ __END__
 
 =head1 NAME
 
-App::Midgen - generate the requires and test requires for Makefile.PL using Module::Install::DSL
+App::Midgen - generate the requires and test requires sections for Makefile.PL
 
 =head1 VERSION
 
-This document describes App::Midgen version 0.07
+This document describes App::Midgen version 0.08
 
 =head1 SYNOPSIS
 
-midgen.pl [options]
+Change to root of package and run
 
- Options:
-   -help	brief help message
-   -output	change format
-   -core	show perl core modules
-   -verbose	take a little peek as to what is going on
-   -base	Don't check for base includes
-   -mojo	Don't be Mojo friendly	
-   -debug	lots of stuff
+ midgen
 
-=head1 OPTIONS
+Now with a Getopt --help or -?
 
-=over 4
+ midgen -?
 
-=item B<--help or -h>
-
-Print a brief help message and exits.
-
-=item B<--output or -o>
-
-By default we do 'dsl' -> Module::Include::DSL
-
- midgen.pl -o dsl	# Module::Include::DSL
- midgen.pl -o mi	# Module::Include
- midgen.pl -o build	# Build.PL
-
-
-=item B<-core or -c>
-
- * Shows modules that are in Perl core
- * some modules have a version number eg; constant, Carp
- * some have a version of 0 eg; strict, English 
-
-=item B<--verbose or -v>
-
-Show file that are being checked
-
-also show contents of base|parent check
-
-=item B<--parent or -p>
-
-alternative  --base or -b
-
-Turn Off - try to include the contents of base|parent modules as well
-
-=item B<--mojo or -m>
-
-Turn Off - the /Mojo/ to Mojolicious catch
-
-=item B<--noisy_children or -n>
-
- * Show a required modules noisy children, as we find them
-
-=item B<--debug or -d>
-
-equivalent of -cv and some :)
-
-=back
+See L<midgen> for more info.
  
 =head1 DESCRIPTION
 
-This started out as a way of generating the core for a Module::Install::DSL Makefile.PL, why DSL because it's nice and clean, so now I can generate the contents when I want, rather than as I add new use and require statments, and because adam kicked me :)
+This started out as a way of generating the core for a Module::Install::DSL Makefile.PL, 
+why DSL because it's nice and clean, so now I can generate the contents when I want, 
+rather than as I add new use and require statements, and because Adam kicked me :)
 
-Change to root of package and run
-
- midgen.pl
-
-Now with a GetOps --help or -?
-
- midgen.pl -?
+For more info and sample output see L<wiki|https://github.com/kevindawson/App-Midgen/wiki>
 
 =head1 METHODS
 
@@ -698,94 +655,29 @@ Now with a GetOps --help or -?
 
 =back
 
-=head1 INTERFACE 
-
-=for author to fill in:
-    Write a separate section listing the public components of the modules
-    interface. These normally consist of either subroutines that may be
-    exported, or methods that may be called on objects belonging to the
-    classes provided by the module.
-
-
-=head1 DIAGNOSTICS
-
-=for author to fill in:
-    List every single error and warning message that the module can
-    generate (even the ones that will "never happen"), with a full
-    explanation of each problem, one or more likely causes, and any
-    suggested remedies.
-
-=over
-
-=item C<< Error message here, perhaps with %s placeholders >>
-
-[Description of error here]
-
-=item C<< Another error message here >>
-
-[Description of error here]
-
-[Et cetera, et cetera]
-
-=back
-
 
 =head1 CONFIGURATION AND ENVIRONMENT
-
-=for author to fill in:
-    A full explanation of any configuration system(s) used by the
-    module, including the names and locations of any configuration
-    files, and the meaning of any environment variables or properties
-    that can be set. These descriptions must also include details of any
-    configuration language used.
   
 App::Midgen requires no configuration files or environment variables.
 
 
 =head1 DEPENDENCIES
 
-=for author to fill in:
-    A list of all the other modules that this module relies upon,
-    including any restrictions on versions, and an indication whether
-    the module is part of the standard Perl distribution, part of the
-    module's distribution, or must be installed separately. ]
-
-None.
-
+L<App::Midgen::Roles>, L<App::Midgen::Output>,
 
 =head1 INCOMPATIBILITIES
 
-=for author to fill in:
-    A list of any modules that this module cannot be used in conjunction
-    with. This may be due to name conflicts in the interface, or
-    competition for system or program resources, or due to internal
-    limitations of Perl (for example, many modules that use source code
-    filters are mutually incompatible).
-
 None reported.
 
 
 =head1 BUGS AND LIMITATIONS
 
-=for author to fill in:
-    A list of known problems with the module, together with some
-    indication Whether they are likely to be fixed in an upcoming
-    release. Also a list of restrictions on the features the module
-    does provide: data types that cannot be handled, performance issues
-    and the circumstances in which they may arise, practical
-    limitations on the size of data sets, special cases that are not
-    (yet) handled, etc.
-
-No bugs have been reported.
-
 Please report any bugs or feature requests to
-C<bug-app-midgen@rt.cpan.org>, or through the web interface at
-L<http://rt.cpan.org>.
+through the web interface at
+L<https://github.com/kevindawson/App-Midgen/issues>.
+If reporting a Bug, also supply the Module info, midgen failed against.
 
-
-
-
-=head1 AUTHORS
+=head1 AUTHOR
 
 Kevin Dawson E<lt>bowtie@cpan.orgE<gt>
 
@@ -795,7 +687,7 @@ none at present
 
 =head1 COPYRIGHT
 
-Copyright E<copy> 2013 AUTHORS and CONTRIBUTORS as listed above.
+Copyright E<copy> 2013 AUTHOR and CONTRIBUTORS as listed above.
 
 =head1 LICENSE
 
@@ -805,6 +697,7 @@ modify it under the same terms as Perl 5 itself.
 =head1 SEE ALSO
 
 L<Perl::PrereqScanner>,
+L<Module::Install::DSL>,
 
 =head1 DISCLAIMER OF WARRANTY
 
